package aexp.location;

import android.app.ListActivity;
import android.content.Context;
import android.content.Intent;
import android.location.LocationProvider;
import android.location.LocationManager;
import android.location.Criteria;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.Menu;
import android.view.Menu.Item;
import android.widget.ListView;
import android.widget.Toast;
import android.widget.ArrayAdapter;
import android.widget.ListAdapter;
import java.util.List;
import java.util.ArrayList;

public class LocationProviderList extends ListActivity
{
    static final String LOG_TAG = "LOCATIONPROVIDER";
	static final String ENDLIST_TEXT = "-- end list --";
	public static final int DISPLAY_LOC = 0;
	private int lastSelected = -1;

    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle icicle)
    {
        super.onCreate(icicle);
        setContentView(R.layout.main);
        getProviderList();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        boolean result = super.onCreateOptionsMenu(menu);
        menu.add(0, DISPLAY_LOC, R.string.display_loc);
        return result;
    }

    @Override
    public boolean onOptionsItemSelected(Item item) {
    	switch (item.getId()) {
    	  case DISPLAY_LOC:
    		displayLocationUpdates();
    		break;

    	}
    	
        return super.onOptionsItemSelected(item);
    }

    @Override
    protected void onListItemClick(ListView l, View v, int position, long id) {
        super.onListItemClick(l, v, position, id);
		lastSelected = position;
		LocationManager lm = (LocationManager)getSystemService(Context.LOCATION_SERVICE);
		ListAdapter la = getListAdapter();
		String item = (String)la.getItem( position );
		if( item.equals( ENDLIST_TEXT ) )
			return;
		Log.d( LOG_TAG, "Item selected: "+item );
		LocationProvider locProvider = (LocationProvider)lm.getProvider( item );
		StringBuffer sb = new StringBuffer();
		sb.append( "Accuracy: "+locProvider.getAccuracy()+"; " );
		sb.append( "Power requirement: " );
		switch( locProvider.getPowerRequirement() ) {
		  case Criteria.NO_REQUIREMENT:
			sb.append( "no requirement" );
			break;

		  case Criteria.POWER_HIGH:
			sb.append( "high" );
			break;

		  case Criteria.POWER_LOW:
			sb.append( "low" );
			break;

		  case Criteria.POWER_MEDIUM:
			sb.append( "medium" );
			break;
		}
		sb.append( "; " );
		sb.append( "Monetary cost: " );
		sb.append( locProvider.hasMonetaryCost() ? "paying" : "free" );
		if( locProvider.requiresCell() )
			sb.append( "; Requires cellular network" );
		if( locProvider.requiresNetwork() )
			sb.append( "; Requires data network" );
		if( locProvider.requiresSatellite() )
			sb.append( "; Requires satellite" );
		if( locProvider.supportsAltitude() )
			sb.append( "; Supports altitude" );
		if( locProvider.supportsBearing() )
			sb.append( "; Supports bearing" );
		if( locProvider.supportsSpeed() )
			sb.append( "; Supports speed" );
        Toast.makeText(this, new String( sb ), Toast.LENGTH_SHORT).show();
    }

    private void getProviderList() {
		LocationManager lm = (LocationManager)getSystemService(Context.LOCATION_SERVICE);
		List locProviderList = lm.getProviders();
        List<String> items = new ArrayList<String>();

        for ( int i = 0 ; i < locProviderList.size() ; ++i ) {
		  LocationProvider locProvider = (LocationProvider)locProviderList.get( i );
	      items.add( locProvider.getName() );
		}
        items.add( ENDLIST_TEXT );
        // Now create an array adapter and set it to display using our row
        ArrayAdapter<String> notes = 
            new ArrayAdapter<String>(this, R.layout.provider_row, items);
        setListAdapter(notes);        
    }

	private void displayLocationUpdates() {
      LocationManager lm = (LocationManager)getSystemService(Context.LOCATION_SERVICE);
	  ListAdapter la = getListAdapter();
	  String item = (String)la.getItem( lastSelected );
	  if( item == null )
			return;
	  if( item.equals( ENDLIST_TEXT ) )
			return;
	  Log.d( LOG_TAG, "displayLocationUpdates/item: "+item );
	  LocationProvider locProvider = (LocationProvider)lm.getProvider( item );
	  Intent i = new Intent();
	  i.setClassName( "aexp.location", "aexp.location.LocationUpdateDisplay" );
	  i.putExtra( "locprovider",item );
	  startActivity( i );
	}

}
