package aexp.location;

import android.app.Activity;
import android.content.Intent;
import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.os.Handler;
import android.location.LocationProvider;
import android.location.LocationManager;
import android.location.Location;
import android.widget.TextView;
import android.widget.Toast;

public class LocationUpdateDisplay extends Activity {
    public static final String LOCUPDATE_ACTION = "aexp.location.LOCATION_UPDATE";
    private static final String LOG_TAG = "LocationUpdateDisplay";
    private static LocationUpdateDisplay appRef = null;
    private Handler uiHandler = new Handler();

    @Override
    public void onCreate(Bundle icicle) {
        super.onCreate(icicle);
		appRef = this;
        setContentView(R.layout.locdisplay);
		String locProviderName = null;
		Bundle extras = getIntent().getExtras();
		if( extras != null ) {
			locProviderName = extras.getString( "locprovider" );
	      if( locProviderName != null )
			activateLocationUpdates( locProviderName );
		}
    }

	@Override
	protected void onDestroy() {
	  super.onDestroy();
      LocationManager lm = (LocationManager)getSystemService(Context.LOCATION_SERVICE);
	  Intent fireIntent = new Intent( LOCUPDATE_ACTION );
	  lm.removeUpdates( fireIntent );
    }

	public static LocationUpdateDisplay getActivityReference() {
	  return appRef;
    }

    public void handleUpdateEvent( String action, Bundle extras ) {
	  if( LOCUPDATE_ACTION.equals( action ) ) {
		if( extras == null )
			Log.e( LOG_TAG, "handleUpdateEvent: extras==null" );
		final Location l = (Location)extras.get( "location" );
        uiHandler.post(new Runnable() {
           public void run() {
			  updateLocationDisplay( l );
           }
        });
	  }
    }


	private void activateLocationUpdates( String locProviderName ) {
      LocationManager lm = (LocationManager)getSystemService(Context.LOCATION_SERVICE);
	  LocationProvider locProvider = (LocationProvider)lm.getProvider( locProviderName );
	  if( locProvider == null )
        Toast.makeText(this, 
				"location provider "+locProviderName+" not found",
				 Toast.LENGTH_SHORT).show();
	  else {
		Location loc = lm.getCurrentLocation( locProviderName );
		updateLocationDisplay( loc );
		Intent fireIntent = new Intent( LOCUPDATE_ACTION );
		lm.requestUpdates( locProvider,0,0,fireIntent );
	  }
	}

	private void updateLocationDisplay( Location loc ) {
	   TextView latTV = (TextView)findViewById(R.id.latitude);
       latTV.setText( "Latitude: "+loc.getLatitude() );
	   TextView longTV = (TextView)findViewById(R.id.longitude);
       longTV.setText( "Longitude: "+loc.getLongitude() );
	   TextView altTV = (TextView)findViewById(R.id.altitude);
       altTV.setText( "Altitude: "+loc.getAltitude() );
	}
}
